/**
 * floater
 * 
 * @category    jQuery plugin
 * @license     http://www.opensource.org/licenses/mit-license.html  MIT License
 * @copyright   2010 RaNa design associates, inc.
 * @author      keisuke YAMAMOTO <keisukey@ranadesign.com>
 * @link        http://kaelab.ranadesign.com/
 * @version     1.1.2
 * @date        Jun 10, 2011
 *
 * コンテンツをスクロールに追従させ、ドキュメントの上下に接着させるプラグイン。
 *
 * [オプション]
 * marginTop:     上の余白
 * marginBottom:  下の余白
 * wait:          0～1(初期値 0.5)。0はナビが通り過ぎるまで待つ。1はナビの末端が出るとすぐ動きだす。
 * speed:         アニメーションにかける時間。
 * easing:        イージング
 * fixed:         trueでposition: fixedに切り替え。初期値はfalse。
 *
 */

(function($) {

    $.fn.extend({

        floater: function(options) {
			//alert("float");		// debug
			var ua = navigator.userAgent;
			if (ua.indexOf('iPhone') > 0 || ua.indexOf('iPod') > 0) {
				var window_height 	= screen.height + 100;
			} else if (ua.indexOf('Android') > 0 && ua.indexOf('Mobile') > 0) {
				var window_height 	= screen.height*2 + 100;
			} else {
				var window_height 	= $(window).height();
			}
            var config = {
                marginTop: 0,
                marginBottom: 0,
                wait: 0.5,  // 0-1
                speed: 1000,
                easing: "swing",
                fixed: false
            };
            $.extend(config, options);
            config.wait = $(this).outerHeight() - window_height * config.wait;
            config.marginTop = parseInt(config.marginTop, 10) || 0;
            config.marginBottom = parseInt(config.marginBottom, 10) || 0;

            $(this).each(function() {
                var self = $(this);
                var d = $(document).height();
                var h = self.outerHeight() + config.marginTop + config.marginBottom;

                if (config.fixed === true) {
                    self._fixed(config);
                    return true;
                }

                self.css("position", "absolute");

                $(window).scroll(function() {
                    var s = $(window).scrollTop();
                    var w = window_height;

                    if (Math.abs(s - self.offset().top) < config.wait) {
                        return;
                    }

                    self.stop(true).animate({
                        top: (d - h) * s / (d - w) + config.marginTop
                    }, {
                        duration: config.speed,
                        easing: config.easing
                    });
                }).scroll();
            });

            return this;
        },
        
        _fixed: function(config) {
            if (!$.support.noCloneChecked && !$.support.style) {				// jQueryのバージョンアップに合わせて修正　2015/04/17
                $(this).css("position", "absolute");
                this[0].style.cssText = "top: expression(documentElement.scrollTop + " + config.marginTop + " + 'px')";
                document.body.style.background = "url(null) fixed";
            } else {
                $(this).css("position", "fixed").css("top", config.marginTop);
            }
        }
        
    });

})(jQuery);

// add by M.okudaira 20120607
(function($) {
	$(function() {
		//alert("add_1");	// debug
		var ua = navigator.userAgent;
		if (ua.indexOf('iPhone') > 0 || ua.indexOf('iPod') > 0) {
			var window_height 	= screen.height + 100;
			var btm_value = 0;
			var top_value = 0;
		} else if (ua.indexOf('Android') > 0 && ua.indexOf('Mobile') > 0) {
			var window_height 	= screen.height*2 + 100;
			var btm_value = 0;
			var top_value = 0;
		} else {
			var window_height 	= $(window).height();
			var btm_value 		= 50;
			var top_value 		= 180;
		}
		
		var isHidden = true;
		$("#c_page_top").hide();
		$("#c_page_top").floater({
			marginTop: window_height - top_value,
			marginBottom: btm_value,
			wait: 0,
			speed: 0,
			easing: "easeInQuad",
			fixed: true
		});
		//alert("add_2");	// debug
		$(window).resize(function() {
			//alert("resize");	// debug
			$("#c_page_top").floater({
				marginTop: window_height - top_value,
				marginBottom: btm_value,
				wait: 0,
				speed: 0,
				easing: "easeInQuad",
				fixed: true
			});
			//alert($(window).scrollTop());	// debug
			$(window).scroll(function() {
				if ($(window).scrollTop() > 400) {
					$("#c_page_top").show();
					isHidden = false;
				}
			});
		});
		//alert("add_3");	// debug
		$(window).scroll(function() {
			//alert("scroll_1");	// debug
			if ($(this).scrollTop() > 400) {
				if (isHidden){	
					//alert("scroll_2");	// debug		
					$("#c_page_top").show();
					isHidden = false;
					//isHidden = true;
				}
			}else {
				if (!isHidden){			
					$("#c_page_top").hide();
					isHidden = true;
				}
			}
		});
		
		$('#c_page_top a').click(function(){
			//alert('top');
			// ページトップへスクロール
			$('html, body').animate({
					'scrollTop': 0
				}, 1000, 'easeOutCubic');
			
			// デフォルトイベントのキャンセル
			return false;
		
		});
		
		
	});
	
	
	
})(jQuery);